searchData={"items":[{"type":"module","title":"TimeSeriesDB","doc":"A time series database that stores data in a directory of files.\n\nExample:\n\n```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\", max_files: 2)\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\niex> TimeSeriesDB.append_row(pid, 2, %{x: 2, y: 3, z: \"world\"})\niex> TimeSeriesDB.append_row(pid, 3, %{x: 3, y: 4, z: \"elixir\"})\niex> TimeSeriesDB.query_range(pid, 1, 2)\n[{1, %{x: 1, y: 2, z: \"hello\"}}, {2, %{x: 2, y: 3, z: \"world\"}}]\niex> TimeSeriesDB.query_multiple(pid, [3, 2])\n[%{x: 3, y: 4, z: \"elixir\"}, %{x: 2, y: 3, z: \"world\"}]\n```","ref":"TimeSeriesDB.html"},{"type":"function","title":"TimeSeriesDB.append_row/2","doc":"Appends a row to the database. Same as `append_row(pid, value)`, but with a nanosecond timestamp as default key.","ref":"TimeSeriesDB.html#append_row/2"},{"type":"function","title":"Examples - TimeSeriesDB.append_row/2","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\", max_files: 2)\niex> TimeSeriesDB.append_row(pid, %{x: 1, y: 2, z: \"hello\"})\n:ok\n```","ref":"TimeSeriesDB.html#append_row/2-examples"},{"type":"function","title":"TimeSeriesDB.append_row/3","doc":"Appends a row to the database.","ref":"TimeSeriesDB.html#append_row/3"},{"type":"function","title":"Examples - TimeSeriesDB.append_row/3","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\", max_files: 2)\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\n:ok\n```","ref":"TimeSeriesDB.html#append_row/3-examples"},{"type":"function","title":"TimeSeriesDB.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TimeSeriesDB.html#child_spec/1"},{"type":"function","title":"TimeSeriesDB.count/1","doc":"Counts the number of rows in the database.","ref":"TimeSeriesDB.html#count/1"},{"type":"function","title":"Examples - TimeSeriesDB.count/1","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\niex> TimeSeriesDB.append_row(pid, 2, %{x: 2, y: 3, z: \"world\"})\niex> TimeSeriesDB.count(pid)\n2\n```","ref":"TimeSeriesDB.html#count/1-examples"},{"type":"function","title":"TimeSeriesDB.count_files/1","doc":"Counts the number of files in the database.","ref":"TimeSeriesDB.html#count_files/1"},{"type":"function","title":"Examples - TimeSeriesDB.count_files/1","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> for x <- 1..20_000, do: TimeSeriesDB.append_row(pid, x, %{x: x, z: String.duplicate(\"hello\", 100)})\niex> TimeSeriesDB.flush(pid)\niex> TimeSeriesDB.count_files(pid) |> length()\n3\n```","ref":"TimeSeriesDB.html#count_files/1-examples"},{"type":"function","title":"TimeSeriesDB.flush/1","doc":"Flushes the database to disk.","ref":"TimeSeriesDB.html#flush/1"},{"type":"function","title":"Examples - TimeSeriesDB.flush/1","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> TimeSeriesDB.flush(pid)\n:ok\n```","ref":"TimeSeriesDB.html#flush/1-examples"},{"type":"function","title":"TimeSeriesDB.newest/1","doc":"Returns the newest timestamp in the database.","ref":"TimeSeriesDB.html#newest/1"},{"type":"function","title":"Examples - TimeSeriesDB.newest/1","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\niex> TimeSeriesDB.append_row(pid, 2, %{x: 2, y: 3, z: \"world\"})\niex> TimeSeriesDB.newest(pid)\n2\n```","ref":"TimeSeriesDB.html#newest/1-examples"},{"type":"function","title":"TimeSeriesDB.oldest/1","doc":"Returns    the oldest timestamp in the database.","ref":"TimeSeriesDB.html#oldest/1"},{"type":"function","title":"TimeSeriesDB.query_multiple/2","doc":"Queries multiple rows from the database.","ref":"TimeSeriesDB.html#query_multiple/2"},{"type":"function","title":"Examples - TimeSeriesDB.query_multiple/2","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\niex> TimeSeriesDB.append_row(pid, 2, %{x: 2, y: 3, z: \"world\"})\niex> TimeSeriesDB.query_multiple(pid, [3, 2, 1])\n[nil, %{x: 2, y: 3, z: \"world\"}, %{x: 1, y: 2, z: \"hello\"}]\n```","ref":"TimeSeriesDB.html#query_multiple/2-examples"},{"type":"function","title":"TimeSeriesDB.query_range/3","doc":"Queries a range of rows from the database.","ref":"TimeSeriesDB.html#query_range/3"},{"type":"function","title":"Examples - TimeSeriesDB.query_range/3","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\", max_files: 2)\niex> TimeSeriesDB.append_row(pid, 1, %{x: 1, y: 2, z: \"hello\"})\niex> TimeSeriesDB.append_row(pid, 2, %{x: 2, y: 3, z: \"world\"})\niex> TimeSeriesDB.query_range(pid, 1, 2)\n[{1, %{x: 1, y: 2, z: \"hello\"}}, {2, %{x: 2, y: 3, z: \"world\"}}]\n```","ref":"TimeSeriesDB.html#query_range/3-examples"},{"type":"function","title":"TimeSeriesDB.start_link/2","doc":"Starts the server.","ref":"TimeSeriesDB.html#start_link/2"},{"type":"function","title":"Options - TimeSeriesDB.start_link/2","doc":"- `:max_files` - The maximum number of files to keep in the database. Defaults to `100`.\n- `:name` - The name of the process.","ref":"TimeSeriesDB.html#start_link/2-options"},{"type":"function","title":"Example: - TimeSeriesDB.start_link/2","doc":"```elixir\niex> {:ok, _pid} = TimeSeriesDB.start_link(\"testdata/test_db\", max_files: 2)\n```","ref":"TimeSeriesDB.html#start_link/2-example"},{"type":"function","title":"TimeSeriesDB.stop/1","doc":"Stops the server.","ref":"TimeSeriesDB.html#stop/1"},{"type":"function","title":"Examples - TimeSeriesDB.stop/1","doc":"```elixir\niex> {:ok, pid} = TimeSeriesDB.start_link(\"testdata/test_db\")\niex> TimeSeriesDB.stop(pid)\n:ok\n```","ref":"TimeSeriesDB.html#stop/1-examples"},{"type":"module","title":"TimeSeriesDB.State","doc":"","ref":"TimeSeriesDB.State.html"},{"type":"function","title":"TimeSeriesDB.State.append_row/3","doc":"","ref":"TimeSeriesDB.State.html#append_row/3"},{"type":"function","title":"TimeSeriesDB.State.append_row!/3","doc":"","ref":"TimeSeriesDB.State.html#append_row!/3"},{"type":"function","title":"TimeSeriesDB.State.count/1","doc":"","ref":"TimeSeriesDB.State.html#count/1"},{"type":"function","title":"TimeSeriesDB.State.count_files/1","doc":"","ref":"TimeSeriesDB.State.html#count_files/1"},{"type":"function","title":"TimeSeriesDB.State.flush/1","doc":"","ref":"TimeSeriesDB.State.html#flush/1"},{"type":"function","title":"TimeSeriesDB.State.init/2","doc":"","ref":"TimeSeriesDB.State.html#init/2"},{"type":"function","title":"TimeSeriesDB.State.newest/1","doc":"","ref":"TimeSeriesDB.State.html#newest/1"},{"type":"function","title":"TimeSeriesDB.State.oldest/1","doc":"","ref":"TimeSeriesDB.State.html#oldest/1"},{"type":"function","title":"TimeSeriesDB.State.query_multiple/2","doc":"","ref":"TimeSeriesDB.State.html#query_multiple/2"},{"type":"function","title":"TimeSeriesDB.State.query_range/3","doc":"","ref":"TimeSeriesDB.State.html#query_range/3"},{"type":"extras","title":"TimeSeriesDB","doc":"# TimeSeriesDB\n\nLog data to disk in zstd compressed files in strict monotonic order. Allows querying of data by time range.","ref":"readme.html"},{"type":"extras","title":"Installation - TimeSeriesDB","doc":"The package can be installed\nby adding `timeseriesdb` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:timeseriesdb, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - TimeSeriesDB","doc":"The documentation for this library can be found at [https://hexdocs.pm/timeseriesdb](https://hexdocs.pm/timeseriesdb).","ref":"readme.html#documentation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}